@@ -89,7 +89,13 @@
     \"collapsed\". What this means is up to the formatter, but it
     generally indicates that most of the field contents will
     hidden unless the user takes some action, such as clicking or
-    hitting <TAB>.  (Currently unimplemented.)"))
+    hitting <TAB>.  (Currently unimplemented.)")
+   (post-format-function
+    :type (or null function)
+    :initarg :post-format-function
+    :initform nil
+    :documentation "A function to be called after formatting is
+    complete.  Probably a major mode."))
   :abstract t
   :documentation "Abstract base class for EBDB formatters.
   Subclass this to produce real formatters.")
@@ -118,19 +124,22 @@ lists, respectively.")
   "Format the body of RECORD, using the fields in FIELDS.")
 
 (cl-defgeneric ebdb-fmt-collect-fields (fmt record &optional fields)
-  "Return a list of RECORD's FIELDS to be formatted.
+  "Return a list of RECORD's FIELDS to be formatted.")
 
-Each element of FIELDS is either a single field instance, or a
-list of field instances.  Which fields are present, how they're
-sorted, and how they're combined into lists is determined by the
-\"exclude\" and \"sort\" slots of FMT.")
+(cl-defgeneric ebdb-fmt-process-fields (fmt record &optional fields)
+  "Process the FIELDS belonging to RECORD.
+This means grouping them into lists containing various formatting
+information, mostly drawn from FMT's `combine' and `collapse'
+slots.")
 
-(cl-defgeneric ebdb-fmt-process-fields (fmt record &optional fields))
-
-(cl-defgeneric ebdb-fmt-sort-fields (fmt record &optional fields))
+(cl-defgeneric ebdb-fmt-sort-fields (fmt record &optional fields)
+  "Sort FIELDS belonging to RECORD according to FMT.")
 
 ;; Do we still need this now that formatters and specs are collapsed?
-(cl-defgeneric ebdb-fmt-compose-field (fmt field-cons record))
+(cl-defgeneric ebdb-fmt-compose-field (fmt field-cons record)
+  "Convert the lists produced by `ebdb-fmt-process-fields'.
+The lists of class instances and formatting information are
+turned into lists holding labels strings and instance strings.")
 
 (cl-defgeneric ebdb-fmt-field (fmt field style record)
   "Format FIELD value of RECORD.
@@ -162,22 +171,22 @@ The FIELD-PLIST structure is that returned by
 `ebdb-fmt-collect-fields'.  It is a plist with three
 keys: :class, :style, and :inst.
 
-This function passes the class and field instances to FMT,
-which formats them appropriately."
+This function passes the class and field instances to FMT, which
+formats them appropriately, and returns a list of (LABEL
+FIELD-STRING1 FIELD-STRING2 ..)."
   (let* ((style (plist-get field-plist :style))
 	 (inst (plist-get field-plist :inst))
 	 (label (ebdb-fmt-field-label fmt
 				      (if (= 1 (length inst))
 					  (car inst)
-				       (plist-get field-plist :class))
+					(plist-get field-plist :class))
 				      style
 				      record)))
     (cons label
-	  (mapconcat
+	  (mapcar
 	   (lambda (f)
 	     (ebdb-fmt-field fmt f style record))
-	   inst
-	   ", "))))
+	   inst))))
 
 (cl-defmethod ebdb-fmt-field-label ((_fmt ebdb-formatter)
 				    (cls (subclass ebdb-field))
@@ -235,88 +244,35 @@ which formats them appropriately."
 (cl-defmethod ebdb-fmt-collect-fields ((fmt ebdb-formatter)
 				       (record ebdb-record)
 				       &optional field-list)
-  (let (f-class)
-    (with-slots (fields notes uuid creation-date timestamp) record
-     (with-slots (exclude include) fmt
-       (dolist (f (append fields (list notes uuid creation-date timestamp)))
-	 (when f
-	   (setq f-class (eieio-object-class-name f))
-	   (when (if include
-		     (ebdb-class-in-list-p f-class include)
-		   (null (ebdb-class-in-list-p f-class exclude)))
-	     (push f field-list))))
-       field-list))))
-
-(cl-defmethod ebdb-fmt-collect-fields ((fmt ebdb-formatter)
-				       (record ebdb-record-entity)
-				       &optional field-list)
-  (with-slots (include exclude primary) fmt
-    (with-slots (mail phone address) record
-      (when (and mail
-		 (if include
-		     (memq 'ebdb-field-mail include)
-		   (null (memq 'ebdb-field-mail exclude))))
-	(if primary
-	    (push (object-assoc 'primary 'priority mail) field-list)
-	  (dolist (m mail)
-	    (push m field-list))))
-      (when (and phone
-		 (if include
-		     (memq 'ebdb-field-phone include)
-		   (null (memq 'ebdb-field-phone exclude))))
-	(dolist (p phone)
-	  (push p field-list)))
-      (when (and address
-		 (if include
-		     (memq 'ebdb-field-address include)
-		   (null (memq 'ebdb-field-address exclude))))
-	(dolist (a address)
-	  (push a field-list)))
-      (cl-call-next-method fmt record field-list))))
-
-(cl-defmethod ebdb-fmt-collect-fields ((fmt ebdb-formatter)
-				       (record ebdb-record-person)
-				       &optional field-list)
-
-  (with-slots (exclude include) fmt
-    (with-slots (aka organizations relations) record
-      (when (and aka
-		 (if include
-		     (memq 'ebdb-field-name include)
-		   (null (memq 'ebdb-field-name exclude))))
-	(dolist (n aka)
-	  (push n field-list)))
-      (when (and organizations
-		 (if include
-		     (memq 'ebdb-field-role include)
-		   (null (memq 'ebdb-field-role exclude))))
-	(dolist (r organizations)
-	  (push r field-list)))
-      (when (and relations
-		 (if include
-		     (memq 'ebdb-field-relation include)
-		   (null (memq 'ebdb-field-relation exclude))))
-	(dolist (r relations)
-	  (push r field-list)))
-      (cl-call-next-method fmt record field-list))))
+  "Collect all fields of RECORD, and filter according to FMT."
+  ;; Remove the `name' slot entry from the list.
+  (let ((fields (append
+		 field-list
+		 (mapcar #'cdr
+			 (seq-remove
+			  ;; The or (null (cdr elt)) is there to
+			  ;; protect against an earlier bug with
+			  ;; timestamps and creation-dates, it could
+			  ;; be removed at some point.
+			  (lambda (elt) (or (eql (car elt) 'name)
+					    (null (cdr elt))))
+ 			  (ebdb-record-current-fields record nil t)))))
+	f-class)
+    (with-slots (exclude include) fmt
+      (seq-filter
+       (lambda (f)
+	 (setq f-class (eieio-object-class-name f))
+	 (if include
+	     (ebdb-class-in-list-p f-class include)
+	   (null (ebdb-class-in-list-p f-class exclude))))
+       fields))))
 
 (cl-defmethod ebdb-fmt-collect-fields ((fmt ebdb-formatter)
 				       (record ebdb-record-organization)
 				       &optional field-list)
-  (with-slots (exclude include) fmt
-    (when (and (slot-value record 'domain)
-	       (if include
-		   (memq 'ebdb-field-domain include)
-		 (null (memq 'ebdb-field-domain exclude))))
-      (push (slot-value record 'domain) field-list))
-    (let ((roles (gethash (ebdb-record-uuid record) ebdb-org-hashtable)))
-      (when (and roles
-		 (if include
-		     (memq 'ebdb-field-role include)
-		   (null (memq 'ebdb-field-role exclude))))
-	(dolist (r roles)
-	  (push r field-list)))
-      (cl-call-next-method fmt record field-list))))
+  (cl-call-next-method
+   fmt record
+   (append field-list (gethash (ebdb-record-uuid record) ebdb-org-hashtable))))
 
 (cl-defmethod ebdb-fmt-sort-fields ((fmt ebdb-formatter)
 				    (_record ebdb-record)
@@ -431,7 +387,9 @@ grouped by field class."
 	(insert (ebdb-fmt-footer formatter records))
 	(set-buffer-file-coding-system fmt-coding)))
     (pop-to-buffer buf)
-    (text-mode)))
+    (let ((f (slot-value formatter 'post-format-function)))
+      (when (fboundp f)
+	(funcall f)))))
 
 ;;;###autoload
 (defun ebdb-format-all-records (&optional formatter)
